@@ -1,7 +1,7 @@
 package App::datecalc;
 
-our $DATE = '2014-12-01'; # DATE
-our $VERSION = '0.05'; # VERSION
+our $DATE = '2015-01-03'; # DATE
+our $VERSION = '0.06'; # VERSION
 
 use 5.010001;
 use strict;
@@ -445,7 +445,7 @@ sub eval {
 }
 
 1;
-#ABSTRACT: Date calculator
+# ABSTRACT: Date calculator
 
 __END__
 
@@ -459,7 +459,7 @@ App::datecalc - Date calculator
 
 =head1 VERSION
 
-This document describes version 0.05 of App::datecalc (from Perl distribution App-datecalc), released on 2014-12-01.
+This document describes version 0.06 of App::datecalc (from Perl distribution App-datecalc), released on 2015-01-03.
 
 =head1 SYNOPSIS
 
@@ -564,12 +564,6 @@ Currently supported calculations:
 
 =head2 eval
 
-=head1 TODO
-
-Support more special date literals: {last,next} {week,month,year,...}, etc.
-
-Variable assignment?
-
 =head1 SEE ALSO
 
 L<DateTime> and L<DateTime::Format::ISO8601>, the backend modules used to do the
@@ -605,7 +599,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by perlancar@cpan.org.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
